@@ -408,7 +408,7 @@ checkCohortTable = function(andromeda) {
   assertions <- checkmate::makeAssertCollection()
   checkmate::assertIntegerish(cohortTableHead$cohort_definition_id, add = assertions)
   checkmate::assertIntegerish(cohortTableHead$subject_id, add = assertions)
-  checkmate::assertInteger(cohortTableHead$cohort_start_date, add = assertions)
-  checkmate::assertInteger(cohortTableHead$cohort_end_date, add = assertions)
+  checkmate::assertIntegerish(cohortTableHead$cohort_start_date, add = assertions)
+  checkmate::assertIntegerish(cohortTableHead$cohort_end_date, add = assertions)
   checkmate::reportAssertions(assertions)
 }
