@@ -14,7 +14,7 @@ test_that("empty treatmentHistory table", {
   tempDirLocal <- file.path(tempdir(), "output")
   localAndromeda <- Andromeda::andromeda()
   
-  localAndromeda$treatmentHistory <- data.frame(
+  localAndromeda$treatmentHistoryFinal <- data.frame(
     personId = numeric(0)
   )
   
@@ -26,9 +26,9 @@ test_that("empty treatmentHistory table", {
 
 # CohortGenerator ----
 test_that("outputPath", {
-  skip_on_ci()
-  skip_on_cran()
   skip_if_not(ableToRun()$CG)
+  skip_on_os(os = "linux")
+  skip_on_cran()
   
   globals <- generateCohortTableCG()
   
@@ -42,41 +42,62 @@ test_that("outputPath", {
   ## file.path(tempDirCG) ----
   tempDirLocal <- file.path(tempdir(), "output")
 
-  export(andromeda, outputPath = tempDirLocal)
+  result <- export(andromeda, outputPath = tempDirLocal)
 
   expect_true(
-    file.exists(file.path(tempDirLocal, "treatmentPathways.csv"))
+    file.exists(file.path(tempDirLocal, "treatment_pathways.csv"))
   )
-
+  
   expect_true(
-    file.exists(file.path(tempDirLocal, "summaryEventDuration.csv"))
+    file.exists(file.path(tempDirLocal, "summary_event_duration.csv"))
   )
-
+  
   expect_true(
-    file.exists(file.path(tempDirLocal, "countsYear.csv"))
+    file.exists(file.path(tempDirLocal, "counts_year.csv"))
   )
-
+  
   expect_true(
-    file.exists(file.path(tempDirLocal, "countsAge.csv"))
+    file.exists(file.path(tempDirLocal, "counts_age.csv"))
   )
-
+  
   expect_true(
-    file.exists(file.path(tempDirLocal, "countsSex.csv"))
+    file.exists(file.path(tempDirLocal, "counts_sex.csv"))
+  )
+  
+  expect_true(
+    file.exists(file.path(tempDirLocal, "attrition.csv"))
+  )
+  
+  expect_true(
+    file.exists(file.path(tempDirLocal, "cdm_source_info.csv"))
+  )
+  
+  expect_true(
+    file.exists(file.path(tempDirLocal, "analyses.csv"))
+  )
+  
+  expect_true(
+    file.exists(file.path(tempDirLocal, "metadata.csv"))
   )
 
   ## 3 ----
   expect_error(
-    TreatmentPatterns::export(andromeda, outputPath = 3),
-    "Variable 'outputPath': No path provided"
+    TreatmentPatterns::export(
+      andromeda,
+      outputPath = 3,
+      nonePaths = TRUE,
+      stratify = TRUE
+    ),
+    "Variable 'outputPath':"
   )
   
   Andromeda::close(andromeda)
 })
 
 test_that("ageWindow", {
-  skip_on_ci()
-  skip_on_cran()
   skip_if_not(ableToRun()$CG)
+  skip_on_os(os = "linux")
+  skip_on_cran()
   
   globals <- generateCohortTableCG()
   
@@ -87,46 +108,46 @@ test_that("ageWindow", {
     cdmSchema = globals$cdmSchema,
     resultSchema = globals$resultSchema
   )
-  
-  tempDirLocal <- file.path(tempdir(), "output")
 
   ## 10 ----
   expect_message(
-    export(
+    result <- export(
       andromeda = andromeda,
-      outputPath = tempDirLocal,
-      ageWindow = 10
+      ageWindow = 10,
+      nonePaths = TRUE,
+      stratify = TRUE
     )
   )
 
-  treatmentPathways <- read.csv(file.path(tempDirLocal, "treatmentPathways.csv"))
+  treatmentPathways <- result$treatment_pathways
 
   expect_true(
     all(c("0-10", "10-20", "20-30", "30-40", "40-50", "all") %in% treatmentPathways$age))
 
   ## c(0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 150) ----
   expect_message(
-    export(
+    result <- export(
       andromeda = andromeda,
-      outputPath = tempDirLocal,
-      ageWindow = c(0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 150)
+      ageWindow = c(0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 150),
+      nonePaths = TRUE,
+      stratify = TRUE
     )
   )
 
-  treatmentPathways <- read.csv(file.path(tempDirLocal, "treatmentPathways.csv"))
+  treatmentPathways <- result$treatment_pathways
 
   expect_true(all(
     c("0-2", "2-4", "4-6", "6-8", "8-10", "10-12",
       "12-14", "14-16", "16-18", "18-150", "all") %in% treatmentPathways$age
   ))
-  
+
   Andromeda::close(andromeda)
 })
 
 test_that("minCellCount", {
-  skip_on_ci()
-  skip_on_cran()
   skip_if_not(ableToRun()$CG)
+  skip_on_os(os = "linux")
+  skip_on_cran()
   
   globals <- generateCohortTableCG()
   
@@ -137,21 +158,20 @@ test_that("minCellCount", {
     cdmSchema = globals$cdmSchema,
     resultSchema = globals$resultSchema
   )
-  
-  tempDirLocal <- file.path(tempdir(), "output")
-  
+
   ## 10 ----
   expect_message(
-    export(
+    result <- export(
       andromeda = andromeda,
-      outputPath = tempDirLocal,
       minCellCount = 10,
-      censorType = "remove"
+      censorType = "remove",
+      nonePaths = TRUE,
+      stratify = TRUE
     ),
     "Removing \\d+ pathways with a frequency <10."
   )
 
-  treatmentPathways <- read.csv(file.path(tempDirLocal, "treatmentPathways.csv"))
+  treatmentPathways <- result$treatment_pathways
 
   expect_equal(min(treatmentPathways$freq), 10)
 
@@ -159,8 +179,9 @@ test_that("minCellCount", {
   expect_error(
     export(
       andromeda = andromeda,
-      outputPath = tempDirLocal,
-      minCellCount = "10"
+      minCellCount = "10",
+      nonePaths = TRUE,
+      stratify = TRUE
     )
   )
   
@@ -168,9 +189,9 @@ test_that("minCellCount", {
 })
 
 test_that("archiveName", {
-  skip_on_ci()
-  skip_on_cran()
   skip_if_not(ableToRun()$CG)
+  skip_on_os(os = "linux")
+  skip_on_cran()
   
   globals <- generateCohortTableCG()
   
@@ -202,7 +223,9 @@ test_that("archiveName", {
     export(
       andromeda = andromeda,
       outputPath = tempDirLocal,
-      archiveName = 3
+      archiveName = 3,
+      nonePaths = TRUE,
+      stratify = TRUE
     )
   )
   
@@ -210,9 +233,9 @@ test_that("archiveName", {
 })
 
 test_that("censorType", {
-  skip_on_ci()
-  skip_on_cran()
   skip_if_not(ableToRun()$CG)
+  skip_on_os(os = "linux")
+  skip_on_cran()
   
   globals <- generateCohortTableCG()
   
@@ -223,21 +246,20 @@ test_that("censorType", {
     cdmSchema = globals$cdmSchema,
     resultSchema = globals$resultSchema
   )
-  
-  tempDirLocal <- file.path(tempdir(), "output")
-  
+
   ## "remove" ----
   expect_message(
-    TreatmentPatterns::export(
+    result <- TreatmentPatterns::export(
       andromeda = andromeda,
-      outputPath = tempDirLocal,
       minCellCount = 10,
-      censorType = "remove"
+      censorType = "remove",
+      nonePaths = TRUE,
+      stratify = TRUE
     ),
     "Removing \\d+ pathways with a frequency <10."
   )
 
-  treatmentPathways <- read.csv(file.path(tempDirLocal, "treatmentPathways.csv"))
+  treatmentPathways <- result$treatment_pathways
 
   expect_equal(min(treatmentPathways$freq), 10)
 
@@ -245,29 +267,31 @@ test_that("censorType", {
   expect_message(
     TreatmentPatterns::export(
       andromeda = andromeda,
-      outputPath = tempDirLocal,
       minCellCount = 10,
-      censorType = "minCellCount"
+      censorType = "minCellCount",
+      nonePaths = TRUE,
+      stratify = TRUE
     ),
     "Censoring \\d+ pathways with a frequency <10 to 10."
   )
   
-  treatmentPathways <- read.csv(file.path(tempDirLocal, "treatmentPathways.csv"))
+  treatmentPathways <- result$treatment_pathways
   
   expect_equal(min(treatmentPathways$freq), 10)
   
   ## "mean" ----
   expect_message(
-    TreatmentPatterns::export(
+    result <- TreatmentPatterns::export(
       andromeda = andromeda,
-      outputPath = tempDirLocal,
       minCellCount = 10,
-      censorType = "mean"
+      censorType = "mean",
+      nonePaths = TRUE,
+      stratify = TRUE
     ),
     "Censoring \\d+ pathways with a frequency <10 to mean."
   )
   
-  treatmentPathways <- read.csv(file.path(tempDirLocal, "treatmentPathways.csv"))
+  treatmentPathways <- result$treatment_pathways
   
   expect_equal(min(treatmentPathways$freq), 2)
   
@@ -275,18 +299,19 @@ test_that("censorType", {
   expect_error(
     export(
       andromeda = andromeda,
-      outputPath = tempDirLocal,
-      censorType = "Stuff"
+      censorType = "Stuff",
+      nonePaths = TRUE,
+      stratify = TRUE
     )
   )
-  
+
   Andromeda::close(andromeda)
 })
 
 # CDMConnector ----
 test_that("outputPath", {
-  skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
+  skip_on_cran()
   
   globals <- generateCohortTableCDMC()
   
@@ -298,32 +323,53 @@ test_that("outputPath", {
   
   tempDirLocal <- file.path(tempdir(), "output")
   
-  export(andromeda, outputPath = tempDirLocal)
+  result <- export(andromeda, outputPath = tempDirLocal)
 
   expect_true(
-    file.exists(file.path(tempDirLocal, "treatmentPathways.csv"))
+    file.exists(file.path(tempDirLocal, "treatment_pathways.csv"))
   )
-
+  
   expect_true(
-    file.exists(file.path(tempDirLocal, "summaryEventDuration.csv"))
+    file.exists(file.path(tempDirLocal, "summary_event_duration.csv"))
   )
-
+  
   expect_true(
-    file.exists(file.path(tempDirLocal, "countsYear.csv"))
+    file.exists(file.path(tempDirLocal, "counts_year.csv"))
   )
-
+  
   expect_true(
-    file.exists(file.path(tempDirLocal, "countsAge.csv"))
+    file.exists(file.path(tempDirLocal, "counts_age.csv"))
   )
-
+  
   expect_true(
-    file.exists(file.path(tempDirLocal, "countsSex.csv"))
+    file.exists(file.path(tempDirLocal, "counts_sex.csv"))
+  )
+  
+  expect_true(
+    file.exists(file.path(tempDirLocal, "attrition.csv"))
+  )
+  
+  expect_true(
+    file.exists(file.path(tempDirLocal, "cdm_source_info.csv"))
+  )
+  
+  expect_true(
+    file.exists(file.path(tempDirLocal, "analyses.csv"))
+  )
+  
+  expect_true(
+    file.exists(file.path(tempDirLocal, "metadata.csv"))
   )
 
   ## 3 ----
   expect_error(
-    export(andromeda, outputPath = 3),
-    "Variable 'outputPath': No path provided"
+    export(
+      andromeda,
+      outputPath = 3,
+      nonePaths = TRUE,
+      stratify = TRUE
+    ),
+    "Variable 'outputPath':"
   )
   
   Andromeda::close(andromeda)
@@ -331,8 +377,8 @@ test_that("outputPath", {
 })
 
 test_that("ageWindow", {
-  skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
+  skip_on_cran()
   
   globals <- generateCohortTableCDMC()
   
@@ -341,32 +387,32 @@ test_that("ageWindow", {
     cohortTableName = globals$cohortTableName,
     cdm = globals$cdm
   )
-  
-  tempDirLocal <- file.path(tempdir(), "output")
-  
+
   ## 10 ----
   expect_message(
-    export(
+    result <- export(
       andromeda = andromeda,
-      outputPath = tempDirLocal,
-      ageWindow = 10
+      ageWindow = 10,
+      nonePaths = TRUE,
+      stratify = TRUE
     )
   )
 
-  treatmentPathways <- read.csv(file.path(tempDirLocal, "treatmentPathways.csv"))
+  treatmentPathways <- result$treatment_pathways
 
   expect_true(all(c("0-10", "10-20", "all") %in% treatmentPathways$age))
 
   ## c(0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 150) ----
   expect_message(
-    export(
+    result <- export(
       andromeda = andromeda,
-      outputPath = tempDirLocal,
-      ageWindow = c(0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 150)
+      ageWindow = c(0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 150),
+      nonePaths = TRUE,
+      stratify = TRUE
     )
   )
 
-  treatmentPathways <- read.csv(file.path(tempDirLocal, "treatmentPathways.csv"))
+  treatmentPathways <- result$treatment_pathways
 
   expect_true(all(
     c("0-2", "2-4", "4-6", "6-8", "8-10", "10-12",
@@ -378,8 +424,8 @@ test_that("ageWindow", {
 })
 
 test_that("minCellCount", {
-  skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
+  skip_on_cran()
   
   globals <- generateCohortTableCDMC()
   
@@ -388,21 +434,20 @@ test_that("minCellCount", {
     cohortTableName = globals$cohortTableName,
     cdm = globals$cdm
   )
-  
-  tempDirLocal <- file.path(tempdir(), "output")
-  
+
   ## 10 ----
   expect_message(
-    export(
+    result <- export(
       andromeda = andromeda,
-      outputPath = tempDirLocal,
       minCellCount = 10,
-      censorType = "remove"
+      censorType = "remove",
+      nonePaths = TRUE,
+      stratify = TRUE
     ),
     "Removing \\d+ pathways with a frequency <10."
   )
 
-  treatmentPathways <- read.csv(file.path(tempDirLocal, "treatmentPathways.csv"))
+  treatmentPathways <- result$treatment_pathways
 
   expect_equal(min(treatmentPathways$freq), 10)
 
@@ -410,8 +455,9 @@ test_that("minCellCount", {
   expect_error(
     export(
       andromeda = andromeda,
-      outputPath = tempDirLocal,
-      minCellCount = "10"
+      minCellCount = "10",
+      nonePaths = TRUE,
+      stratify = TRUE
     )
   )
   
@@ -420,8 +466,8 @@ test_that("minCellCount", {
 })
 
 test_that("archiveName", {
-  skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
+  skip_on_cran()
   
   globals <- generateCohortTableCDMC()
   
@@ -432,13 +478,15 @@ test_that("archiveName", {
   )
   
   tempDirLocal <- file.path(tempdir(), "output")
-  
+
   ## "output.zip" ----
   expect_message(
-    export(
+    result <- export(
       andromeda = andromeda,
       outputPath = tempDirLocal,
-      archiveName = "output.zip"
+      archiveName = "output.zip",
+      nonePaths = TRUE,
+      stratify = TRUE
     )
   )
 
@@ -451,7 +499,9 @@ test_that("archiveName", {
     export(
       andromeda = andromeda,
       outputPath = tempDirLocal,
-      archiveName = 3
+      archiveName = 3,
+      nonePaths = TRUE,
+      stratify = TRUE
     )
   )
   
@@ -460,8 +510,8 @@ test_that("archiveName", {
 })
 
 test_that("censorType", {
-  skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
+  skip_on_cran()
   
   globals <- generateCohortTableCDMC()
   
@@ -470,51 +520,52 @@ test_that("censorType", {
     cohortTableName = globals$cohortTableName,
     cdm = globals$cdm
   )
-  
-  tempDirLocal <- file.path(tempdir(), "output")
-  
+
   ## "remove" ----
   expect_message(
-    export(
+    result <- export(
       andromeda = andromeda,
-      outputPath = tempDirLocal,
       minCellCount = 10,
-      censorType = "remove"
+      censorType = "remove",
+      nonePaths = TRUE,
+      stratify = TRUE
     ),
     "Removing \\d+ pathways with a frequency <10."
   )
   
-  treatmentPathways <- read.csv(file.path(tempDirLocal, "treatmentPathways.csv"))
-  
+  treatmentPathways <- result$treatment_pathways
+
   expect_equal(min(treatmentPathways$freq), 10)
-  
+
   ## "minCellCount" ----
   expect_message(
-    export(
+    result <- export(
       andromeda = andromeda,
-      outputPath = tempDirLocal,
       minCellCount = 10,
-      censorType = "minCellCount"
+      censorType = "minCellCount",
+      nonePaths = TRUE,
+      stratify = TRUE
     ),
     "Censoring \\d+ pathways with a frequency <10 to 10."
   )
   
-  treatmentPathways <- read.csv(file.path(tempDirLocal, "treatmentPathways.csv"))
-  
+  treatmentPathways <- result$treatment_pathways
+
   expect_equal(min(treatmentPathways$freq), 10)
-  
+
   ## "mean" ----
   expect_message(
-    export(
+    result <- export(
       andromeda = andromeda,
-      outputPath = tempDirLocal,
       minCellCount = 10,
-      censorType = "mean"
+      censorType = "mean",
+      nonePaths = TRUE,
+      stratify = TRUE
     ),
     "Censoring \\d+ pathways with a frequency <10 to mean."
   )
   
-  treatmentPathways <- read.csv(file.path(tempDirLocal, "treatmentPathways.csv"))
+  treatmentPathways <- result$treatment_pathways
   
   expect_equal(min(treatmentPathways$freq), 2)
   
@@ -523,7 +574,9 @@ test_that("censorType", {
     export(
       andromeda = andromeda,
       outputPath = tempDirLocal,
-      censorType = "Stuff"
+      censorType = "Stuff",
+      nonePaths = TRUE,
+      stratify = TRUE
     )
   )
   
@@ -532,30 +585,30 @@ test_that("censorType", {
 })
 
 test_that("counts", {
-  skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
-  
+  skip_on_cran()
+
   globals <- generateCohortTableCDMC()
-  
+
   andromeda <- TreatmentPatterns::computePathways(
     cohorts = globals$cohorts,
     cohortTableName = globals$cohortTableName,
     cdm = globals$cdm
   )
-  
-  tempDirLocal <- file.path(tempdir(), "output")
-  
+
   ## "remove" ----
-  TreatmentPatterns::export(
+  result <- TreatmentPatterns::export(
     andromeda = andromeda,
-    outputPath = tempDirLocal,
-    minCellCount = 1, ageWindow = c(0, 18, 150)
+    minCellCount = 1,
+    ageWindow = c(0, 18, 150),
+    nonePaths = TRUE,
+    stratify = TRUE
   )
-  
-  treatmentPathways <- read.csv(file.path(tempDirLocal, "treatmentPathways.csv"))
+
+  treatmentPathways <- result$treatment_pathways
 
   totalAll <- treatmentPathways %>%
-    dplyr::filter(.data$age == "all", .data$sex == "all", indexYear == "all") %>%
+    dplyr::filter(.data$age == "all", .data$sex == "all", index_year == "all") %>%
     summarize(sum(freq)) %>%
     pull()
   
@@ -564,7 +617,7 @@ test_that("counts", {
   sexes <- sexes[sexes != "all"]
   totalSexes <- lapply(sexes, function(sexGroup) {
     treatmentPathways %>%
-      dplyr::filter(.data$age == "all", .data$sex == sexGroup, indexYear == "all") %>%
+      dplyr::filter(.data$age == "all", .data$sex == sexGroup, index_year == "all") %>%
       summarize(sum(freq)) %>%
       pull()
   }) %>% unlist() %>% sum()
@@ -576,7 +629,7 @@ test_that("counts", {
   ages <- ages[ages != "all"] %>% unlist()
   totalAges <- lapply(ages, function(ageGroup) {
     treatmentPathways %>%
-      dplyr::filter(.data$age == ageGroup, .data$sex == "all", indexYear == "all") %>%
+      dplyr::filter(.data$age == ageGroup, .data$sex == "all", index_year == "all") %>%
       summarize(sum(freq)) %>%
       pull()
   }) %>% unlist() %>% sum()
@@ -584,11 +637,11 @@ test_that("counts", {
   expect_identical(totalAll, totalAges)
   
   # Years
-  years <- unique(treatmentPathways$indexYear)
+  years <- unique(treatmentPathways$index_year)
   years <- years[years != "all"]
   totalYears <- lapply(years, function(year) {
     treatmentPathways %>%
-      dplyr::filter(.data$age == "all", .data$sex == "all", indexYear == year) %>%
+      dplyr::filter(.data$age == "all", .data$sex == "all", index_year == year) %>%
       summarize(sum(freq)) %>%
       pull()
   }) %>% unlist() %>% sum()
@@ -600,8 +653,8 @@ test_that("counts", {
 })
 
 test_that("attrition", {
-  skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
+  skip_on_cran()
 
   globals <- generateCohortTableCDMC()
   
@@ -615,7 +668,9 @@ test_that("attrition", {
   suppressWarnings(
     TreatmentPatterns::export(
       andromeda = andromeda,
-      outputPath = tempDirLocal
+      outputPath = tempDirLocal,
+      nonePaths = TRUE,
+      stratify = TRUE
     )
   )
   
@@ -624,3 +679,93 @@ test_that("attrition", {
   Andromeda::close(andromeda)
   DBI::dbDisconnect(globals$con, shutdown = TRUE)
 })
+
+test_that("stratify, none paths", {
+  skip_if_not(ableToRun()$CDMC)
+  skip_on_cran()
+
+  globals <- suppressWarnings(generateCohortTableCDMC())
+
+  andromeda <- TreatmentPatterns::computePathways(
+    cohorts = globals$cohorts,
+    cohortTableName = globals$cohortTableName,
+    cdm = globals$cdm
+  )
+
+  result <- export(
+    andromeda = andromeda,
+    nonePaths = TRUE,
+    stratify = TRUE
+  )
+
+  tt <- result$treatment_pathways
+
+  result <- TreatmentPatterns::export(
+    andromeda = andromeda,
+    nonePaths = TRUE,
+    stratify = FALSE
+  )
+
+  tf <- result$treatment_pathways
+
+  result <- TreatmentPatterns::export(
+    andromeda = andromeda,
+    nonePaths = FALSE,
+    stratify = TRUE
+  )
+
+  ft <- result$treatment_pathways
+
+  result <- TreatmentPatterns::export(
+    andromeda = andromeda,
+    nonePaths = FALSE,
+    stratify = FALSE
+  )
+
+  ff <- result$treatment_pathways
+
+  # No strata
+  expect_true(nrow(ff) + 1 == nrow(tf))
+  expect_identical(
+    ff,
+    tf %>%
+      dplyr::filter(.data$pathway != "None")
+  )
+
+  # Strata
+  expect_identical(
+    ft,
+    tt %>%
+      filter(.data$pathway != "None")
+  )
+
+  # Pair-wise comparison
+  ages <- unique(tt$age)
+  sexes <- unique(tt$sex)
+  years <- unique(tt$index_year)
+
+  for (age in ages) {
+    for (sex in sexes) {
+      for (year in years) {
+        n1 <- tt %>%
+          dplyr::filter(
+            .data$age == age,
+            .data$sex == sex,
+            .data$index_year == year,
+            .data$pathway != "None"
+          )
+
+        n2 <- ft %>%
+          dplyr::filter(
+            .data$age == age,
+            .data$sex == sex,
+            .data$index_year == year
+          )
+        expect_identical(n1, n2)
+      }
+    }
+  }
+
+  Andromeda::close(andromeda)
+  DBI::dbDisconnect(globals$con, shutdown = TRUE)
+})
